package com.fs.live.mapper;


import com.fs.live.domain.LiveOrderLogs;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 订单操作记录Mapper接口
 *
 * @author fs
 * @date 2025-07-08
 */
public interface LiveOrderLogsMapper {
    /**
     * 查询订单操作记录
     *
     * @param logsId 订单操作记录主键
     * @return 订单操作记录
     */
    LiveOrderLogs selectLiveOrderLogsByLogsId(String logsId);

    /**
     * 查询订单操作记录列表
     *
     * @param liveOrderLogs 订单操作记录
     * @return 订单操作记录集合
     */
    List<LiveOrderLogs> selectLiveOrderLogsList(LiveOrderLogs liveOrderLogs);

    /**
     * 新增订单操作记录
     *
     * @param liveOrderLogs 订单操作记录
     * @return 结果
     */
    int insertLiveOrderLogs(LiveOrderLogs liveOrderLogs);

    /**
     * 修改订单操作记录
     *
     * @param liveOrderLogs 订单操作记录
     * @return 结果
     */
    int updateLiveOrderLogs(LiveOrderLogs liveOrderLogs);

    /**
     * 删除订单操作记录
     *
     * @param logsId 订单操作记录主键
     * @return 结果
     */
    int deleteLiveOrderLogsByLogsId(String logsId);

    /**
     * 批量删除订单操作记录
     *
     * @param logsIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteLiveOrderLogsByLogsIds(String[] logsIds);

    @Select("select * from live_order_logs where order_id = #{orderId}")
    List<LiveOrderLogs> selectLiveOrderLogsByOrderId(@Param("orderId") Long orderId);
}
